@@ -14,11 +14,12 @@ import sys
 
 import znjson
 
-from .core import Node
-from .interface import DVCInterface
-from .project import ZnTrackProject
-from .utils import config
-from .utils.serializer import MethodConverter, ZnTrackTypeConverter
+from zntrack.core.base import Node
+from zntrack.core.functions.decorator import NodeConfig, nodify
+from zntrack.interface.base import DVCInterface
+from zntrack.project.zntrack_project import ZnTrackProject
+from zntrack.utils.config import config
+from zntrack.utils.serializer import MethodConverter, ZnTrackTypeConverter
 
 # register converters
 znjson.config.ACTIVE_CONVERTER = [
@@ -27,21 +28,28 @@ znjson.config.ACTIVE_CONVERTER = [
     MethodConverter,
 ]
 try:
-    znjson.register(znjson.NumpyConverter)
+    znjson.register([znjson.NumpyConverter, znjson.SmallNumpyConverter])
 except AttributeError:
     pass
 
 #
-__all__ = ["Node", "ZnTrackProject", "DVCInterface", "config"]
+__all__ = [
+    Node.__name__,
+    ZnTrackProject.__name__,
+    DVCInterface.__name__,
+    "config",
+    nodify.__name__,
+    NodeConfig.__name__,
+]
 
-__version__ = "0.3.0"
+__version__ = "0.3.5"
 
 logger = logging.getLogger(__name__)
 logger.setLevel(logging.INFO)
 
 # Formatter for advanced logging
 # formatter = logging.Formatter('%(asctime)s - %(name)s - %(levelname)s - %(message)s')
-formatter = logging.Formatter("%(asctime)s (%(levelname)s): %(message)s")
+formatter = logging.Formatter("%(asctime)s %(module)s (%(levelname)s): %(message)s")
 
 channel = logging.StreamHandler(sys.stdout)
 channel.setLevel(logging.DEBUG)
