@@ -23,7 +23,6 @@ from importlib import import_module
 
 import znjson
 
-import zntrack
 from zntrack.core.base import Node
 
 log = logging.getLogger(__name__)
@@ -56,6 +55,7 @@ class ZnTrackTypeConverter(znjson.ConverterBase):
 
 
 class MethodConverter(znjson.ConverterBase):
+    """ZnJSON Converter for zn.method attributes"""
 
     representation = "zn.method"
 
@@ -69,12 +69,11 @@ class MethodConverter(znjson.ConverterBase):
 
         # If using Jupyter Notebooks
 
-        if zntrack.config.nb_name is not None:
-            # if the class is originally imported from main,
-            #  it will be copied to the same module path as the
-            #  ZnTrack Node source code.
-            if methods["module"] == "__main__":
-                methods["module"] = obj.znjson_module
+        # if the class is originally imported from main,
+        #  it will be copied to the same module path as the
+        #  ZnTrack Node source code.
+        if methods["module"] == "__main__":
+            methods["module"] = obj.znjson_module
 
         for key in inspect.signature(obj.__class__.__init__).parameters:
             if key == "self":
@@ -84,12 +83,12 @@ class MethodConverter(znjson.ConverterBase):
                 continue
             try:
                 methods["kwargs"][key] = getattr(obj, key)
-            except AttributeError:
+            except AttributeError as error:
                 raise AttributeError(
                     f"Could not find {key} in passed method! Please use "
                     "@check_signature from ZnTrack to check that the method signature"
                     " fits the method attributes"
-                )
+                ) from error
 
         return methods
 
